@@ -1,5 +1,5 @@
 package WWW::LinkChecker::Internal::App::Command::check;
-$WWW::LinkChecker::Internal::App::Command::check::VERSION = '0.10.0';
+$WWW::LinkChecker::Internal::App::Command::check::VERSION = '0.12.0';
 use strict;
 use warnings;
 use 5.014;
@@ -24,6 +24,7 @@ sub opt_spec
         [ "base=s",                "Base URL", ],
         [ 'before-insert-skip=s@', "before-insert-skip regexes", ],
         [ 'pre-skip=s@',           "pre-skip regexes", ],
+        [ 'only-check-site-flow!', 'only-check-site-flow!', ],
         [ 'start=s',               "alternative start URL", ],
         [ 'state-filename=s' => 'filename to keep the state', ],
     );
@@ -45,9 +46,10 @@ sub execute
             base_url           => $base_url,
             before_insert_skip =>
                 $self->_regexify( $opt->{before_insert_skip} ),
-            pre_skip       => $self->_regexify( $opt->{pre_skip} ),
-            start_url      => $opt->{start},
-            state_filename => $opt->{state_filename},
+            only_check_site_flow => $opt->{only_check_site_flow},
+            pre_skip             => $self->_regexify( $opt->{pre_skip} ),
+            start_url            => $opt->{start},
+            state_filename       => $opt->{state_filename},
         }
     )->run(
         {
@@ -80,7 +82,7 @@ __END__
 
 =head1 VERSION
 
-version 0.10.0
+version 0.12.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -174,7 +176,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Shlomi Fish.
+This software is Copyright (c) 2023 by Shlomi Fish.
 
 This is free software, licensed under:
 
